@@ -1,16 +1,17 @@
 import requests
-from sent.methods.messages import SendMessage, copyMessage, forwardMessage, editMessageText, deleteMessageText
+# from sent.methods.messages import  CopyMessage, SendMessage, ForwardMessage, EditMessageText, DeleteMessageText
 from sent.methods.authentication import GetMe, LogOut, Close
+from sent.methods.messages import  SendMessage
 
 class Telegram:
     def __init__(self, token):
         self.token = token
         self.url = f"https://api.telegram.org/bot{token}/"
         self.send_message = SendMessage(token).send_message
-        self.delete_message_text = deleteMessageText(token).delete_message_text
-        self.copy_message = copyMessage(token).copy_message
-        self.forward_message = forwardMessage(token).forward_message
-        self.edit_message_text = editMessageText(token).edit_message_text
+        # self.delete_message_text = DeleteMessageText(token).delete_message_text
+        # self.copy_message = CopyMessage(token).copy_message
+        # self.forward_message = ForwardMessage(token).forward_message
+        # self.edit_message_text = EditMessageText(token).edit_message_text
         self.get_me = GetMe(token).get_me
         self.log_out = LogOut(token).log_out
         self.close = Close(token).close
